import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range(['#c11d1d', '#eae600']);

const radiusScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range([20, 15]);

const xPosition = (d, i) => i * 80 + 40;

export const fruitBowl = (selection, props) => {
  
  const { 
    fruits, 
    height, 
    setSelectedFruit, 
    selectedFruit } = props;
  // This is just the update selection. 
  const circles = selection
  	.selectAll('circle').data(fruits, d => d.id);
  
  circles.enter().append('circle')
      .attr('cx', xPosition)
      .attr('cy', height/2)
      .attr('r', 0)
  	.merge(circles)
      .attr('fill', d => colorScale(d.type))
  		.attr('stroke-width', 3)
  		.attr('stroke', d => d.id === selectedFruit 
            ? 'black'
            : 'none')
  		.on('mouseover', d => setSelectedFruit(d.id) )
  		.on('mouseout', () => setSelectedFruit(null) )
  	.transition().duration(1000)
      .attr('cx', xPosition)
      .attr('r', d => radiusScale(d.type))

  
  circles.exit()
    .transition().duration(1000)
    	.attr('r', 0)
    .remove();
};
